modelicares.exps.doe — ModelicaRes v0.7.1 Documentation
Description: Python module to set up, plot, and analyze Modelica simulations
Keywords: Modelica, Python, plot, results, simulation, experiment

### Navigation

- index
- modules |
- next |
- previous |
- ModelicaRes v0.7.1 Documentation »

# `modelicares.exps.doe`

Functions to design experiments (i.e., design of experiments (DOE))

These can be passed to the design argument of `exps.gen_experiments()`.

`modelicares.exps.doe.` `aslisted`(*space)

  Step through all the entries together (jointly or element-wise).

  The set of experiments will terminate at end of the shortest list.

  Example

      >>> from modelicares import *

      >>> settings = doe.aslisted([0, 1], [0, 1], [0, 1, 2])
      >>> for s in settings:
      ...     print(s)
      (0, 0, 0)
      (1, 1, 1)

`modelicares.exps.doe.` `fullfact`(*space)

  Full-factorial DOE.

  Example

      >>> from modelicares import *

      >>> settings = doe.fullfact([0, 1], [0, 1], [0, 1, 2])
      >>> for s in settings:
      ...     print(s)
      (0, 0, 0)
      (0, 0, 1)
      (0, 0, 2)
      (0, 1, 0)
      (0, 1, 1)
      (0, 1, 2)
      (1, 0, 0)
      (1, 0, 1)
      (1, 0, 2)
      (1, 1, 0)
      (1, 1, 1)
      (1, 1, 2)

`modelicares.exps.doe.` `ofat`(*space)

  One-factor-at-a-time or OFAT method

  The first entry in each sublist is taken as the baseline value for that dimension.

  Example

      >>> from modelicares import *

      >>> settings = doe.ofat([0, 1], [0, 1], [0, 1, 2])
      >>> for s in settings:
      ...     print(s)
      (0, 0, 0)
      (1, 0, 0)
      (0, 1, 0)
      (0, 0, 1)
      (0, 0, 2)

### Navigation

- index
- modules |
- next |
- previous |
- ModelicaRes v0.7.1 Documentation »